@@ -9,10 +9,16 @@ CDSL Corpus Management
 import logging
 from pathlib import Path
 from dataclasses import dataclass, field
+from typing import Dict, Generator, List, Tuple
 
 import bs4
 import requests
 
+from .models import (
+    Lexicon, Entry,
+    MWLexicon, MWEntry,
+    AP90Lexicon, AP90Entry
+)
 from .lexicon import CDSLDict
 from .constants import (
     SERVER_URL,
@@ -24,6 +30,13 @@ from .constants import (
 
 ###############################################################################
 
+DEFAULT_MODEL_MAP = {
+    "MW": (MWLexicon, MWEntry),
+    "AP90": (AP90Lexicon, AP90Entry),
+}
+
+###############################################################################
+
 LOGGER = logging.getLogger(__name__)
 
 ###############################################################################
@@ -36,7 +49,7 @@ class CDSLCorpus:
 
     Refers to a CDSL installation instance at the location `data_dir`.
     """
-    data_dir: str = field(default=None)
+    data_dir: str or Path = field(default=None)
     input_scheme: str = field(repr=False, default=DEFAULT_SCHEME)
     output_scheme: str = field(repr=False, default=DEFAULT_SCHEME)
     transliterate_keys: bool = field(repr=False, default=True)
@@ -54,20 +67,31 @@ class CDSLCorpus:
         self.dicts = {}
         self.get_available_dicts()
 
-    def __getattr__(self, attr: str):
+    # ----------------------------------------------------------------------- #
+
+    def __getattr__(self, attr: str) -> CDSLDict:
         if attr in self.dicts:
             return self.dicts[attr]
         else:
             raise AttributeError
 
-    # ----------------------------------------------------------------------- #
+    def __getitem__(self, item: str) -> CDSLDict:
+        if item in self.dicts:
+            return self.dicts[item]
+        else:
+            raise KeyError(f"Dictionary '{item}' is not setup.")
 
-    def __iter__(self):
+    def __iter__(self) -> Generator[CDSLDict, None, None]:
         yield from self.dicts.values()
 
     # ----------------------------------------------------------------------- #
 
-    def setup(self, dict_ids: list = None, update: bool = False):
+    def setup(
+        self,
+        dict_ids: list = None,
+        update: bool = False,
+        model_map: Dict[str, Tuple[Lexicon, Entry]] = None
+    ) -> bool:
         """Setup CDSL dictionaries in bulk
 
         Calls `CDSLDict.setup()` on every `CDSLDict`, and if successful, also
@@ -84,6 +108,18 @@ class CDSLCorpus:
             If True, and update check is performed for every dictionary in
             `dict_ids`, and if available, the updated version is installed
             The default is False.
+        lexicon_model : object, optional
+            Lexicon model argument passed to `CDSLDict.connect()`
+            The default is None.
+        entry_model : object, optional
+            Entry model argument passed to `CDSLDict.connect()`
+            The default is None.
+        model_map : dict, optional
+            Map of dictionary ID to a tuple of lexicon model and entry model.
+            The argument is used to specify `lexicon_model` and `entry_model`
+            arguments passed to `CDSLDict.connect()`.
+            If None, the default map `DEFAULT_MODEL_MAP` will be used.
+            The default is None.
 
         Returns
         -------
@@ -120,7 +156,18 @@ class CDSLCorpus:
             )
             status.append(success)
             if success:
-                cdsl_dict.connect()
+                if model_map is None:
+                    model_map = DEFAULT_MODEL_MAP
+
+                lexicon_model, entry_model = model_map.get(
+                    cdsl_dict.id,
+                    (None, None)
+                )
+
+                cdsl_dict.connect(
+                    lexicon_model=lexicon_model,
+                    entry_model=entry_model
+                )
                 self.dicts[dict_id] = cdsl_dict
 
         return bool(status) and all(status)
@@ -129,15 +176,15 @@ class CDSLCorpus:
 
     def search(
         self,
-        pattern,
-        dict_ids=None,
-        input_scheme=None,
-        output_scheme=None,
-        ignore_case=False,
-        limit=None,
-        offset=None,
-        omit_empty=True
-    ):
+        pattern: str,
+        dict_ids: List[str] = None,
+        input_scheme: str = None,
+        output_scheme: str = None,
+        ignore_case: bool = False,
+        limit: int = None,
+        offset: int = None,
+        omit_empty: bool = True
+    ) -> Dict[str, List[Entry]]:
         """Search in multiple dictionaries from the corpus
 
         Parameters
@@ -207,7 +254,7 @@ class CDSLCorpus:
 
     # ----------------------------------------------------------------------- #
 
-    def get_available_dicts(self):
+    def get_available_dicts(self) -> Dict[str, CDSLDict]:
         """
         Fetch a list of dictionaries available for download from CDSL
 
@@ -247,7 +294,7 @@ class CDSLCorpus:
 
     # ----------------------------------------------------------------------- #
 
-    def get_installed_dicts(self):
+    def get_installed_dicts(self) -> Dict[str, CDSLDict]:
         """Fetch a list of dictionaries installed locally"""
         dictionaries = {}
         dict_ids = [path.name for path in self.dict_dir.glob("*")]
