@@ -10,6 +10,7 @@ from pathlib import Path
 from dataclasses import dataclass, field
 from functools import lru_cache
 import zipfile
+from typing import Dict, Generator, List
 
 from peewee import fn
 from playhouse.db_url import connect
@@ -21,8 +22,7 @@ from indic_transliteration.sanscript import transliterate
 
 from .utils import validate_scheme
 from .models import (
-    MWLexicon, MWEntry,
-    AP90Lexicon, AP90Entry,
+    Lexicon, Entry,
     lexicon_constructor, entry_constructor
 )
 from .constants import (
@@ -36,13 +36,6 @@ LOGGER = logging.getLogger(__name__)
 
 ###############################################################################
 
-DEFAULT_MODEL_MAP = {
-    "MW": (MWLexicon, MWEntry),
-    "AP90": (AP90Lexicon, AP90Entry),
-}
-
-###############################################################################
-
 
 @dataclass(eq=False)
 class CDSLDict:
@@ -67,17 +60,25 @@ class CDSLDict:
 
     # ----------------------------------------------------------------------- #
 
-    def __iter__(self):
+    def __getitem__(self, item: str) -> Entry:
+        result = self.entry(item)
+        if result is None:
+            raise KeyError(f"Entry with ID '{item}' not found.")
+        else:
+            return result
+
+    def __iter__(self) -> Generator[Entry, None, None]:
         for entry in self._lexicon.select():
             yield self._entry(
                 entry,
+                lexicon_id=self.id,
                 scheme=self.output_scheme,
                 transliterate_keys=self.transliterate_keys
             )
 
     # ----------------------------------------------------------------------- #
 
-    def download(self, download_dir):
+    def download(self, download_dir: str or Path) -> bool:
         """Download and extract dictionary data
 
         Parameters
@@ -153,7 +154,12 @@ class CDSLDict:
             LOGGER.info(f"Data for dictionary '{self.id}' is up-to-date.")
         return True
 
-    def setup(self, data_dir, symlink_dir=None, update=False):
+    def setup(
+        self,
+        data_dir: str or Path,
+        symlink_dir: str or Path = None,
+        update: bool = False
+    ) -> bool:
         """Setup the dictionary database path
 
         Parameters
@@ -204,9 +210,9 @@ class CDSLDict:
 
     def set_scheme(
         self,
-        input_scheme=None,
-        output_scheme=None,
-        transliterate_keys=None
+        input_scheme: str = None,
+        output_scheme: str = None,
+        transliterate_keys: bool = None
     ):
         """Set transliteration scheme for the dictionary instance
 
@@ -245,7 +251,11 @@ class CDSLDict:
 
     # ----------------------------------------------------------------------- #
 
-    def connect(self, lexicon_model=None, entry_model=None, model_map=None):
+    def connect(
+        self,
+        lexicon_model: Lexicon = None,
+        entry_model: Entry = None
+    ):
         """
         Connect to the SQLite database
 
@@ -269,22 +279,13 @@ class CDSLDict:
         entry_model : object, optional
             Entry model.
             The default is None.
-        model_map : dict, optional
-            Map of dictionary ID to a tuple of lexicon model and entry model
-            If None, the default map `MODEL_MAP` will be used.
-            The default is None.
         """
         if lexicon_model is not None and entry_model is not None:
             self._lexicon = lexicon_model
             self._entry = entry_model
         else:
-            if model_map is None:
-                model_map = DEFAULT_MODEL_MAP
-            if self.id in model_map:
-                self._lexicon, self._entry = model_map[self.id]
-            else:
-                self._lexicon = lexicon_constructor(self.id)
-                self._entry = entry_constructor(self.id)
+            self._lexicon = lexicon_constructor(self.id)
+            self._entry = entry_constructor(self.id)
 
         db_url = f"sqlite:///{self.db}"
         self._lexicon.bind(connect(db_url))
@@ -294,7 +295,7 @@ class CDSLDict:
     # ----------------------------------------------------------------------- #
 
     @lru_cache(maxsize=1)
-    def stats(self, top=10):
+    def stats(self, top: int = 10) -> Dict:
         """Display statistics about the lexicon
 
         Parameters
@@ -343,13 +344,13 @@ class CDSLDict:
     @lru_cache(maxsize=4096)
     def search(
         self,
-        pattern,
-        input_scheme=None,
-        output_scheme=None,
-        ignore_case=False,
-        limit=None,
-        offset=None
-    ):
+        pattern: str,
+        input_scheme: str = None,
+        output_scheme: str = None,
+        ignore_case: str = False,
+        limit: int = None,
+        offset: int = None
+    ) -> List[Entry]:
         """Search in the dictionary
 
         Parameters
@@ -390,13 +391,14 @@ class CDSLDict:
         return [
             self._entry(
                 result,
+                lexicon_id=self.id,
                 scheme=output_scheme,
                 transliterate_keys=self.transliterate_keys
             )
             for result in search_query.limit(limit).offset(offset)
         ]
 
-    def entry(self, entry_id, output_scheme=None):
+    def entry(self, entry_id: str, output_scheme: str = None) -> Entry or None:
         """Get an entry by ID
 
         Parameters
@@ -411,26 +413,32 @@ class CDSLDict:
         Returns
         -------
         object
-            Lexicon Entry
+            If the `entry_id` is valid, `Entry` with the matching ID
+            otherwise, None.
         """
 
         output_scheme = validate_scheme(output_scheme) or self.output_scheme
         try:
             return self._entry(
                 self._lexicon.get(self._lexicon.id == entry_id),
+                lexicon_id=self.id,
                 scheme=output_scheme,
                 transliterate_keys=self.transliterate_keys
             )
         except Exception:
-            LOGGER.error(f"No entry with ID '{entry_id}' was found")
+            LOGGER.error(f"Entry with ID '{entry_id}' not found.")
 
-    def dump(self, output_path=None, output_scheme=None):
+    def dump(
+        self,
+        output_path: str or Path = None,
+        output_scheme: str = None
+    ) -> List[Dict[str, str]]:
         """
         Dump data as JSON
 
         Parameters
         ----------
-        output_path : str or None, optional
+        output_path : str or Path, optional
             Path to the output JSON file.
             If None, the data isn't written to the disk, only returned.
             The default is None.
@@ -451,6 +459,7 @@ class CDSLDict:
             for entry in (
                 self._entry(
                     result,
+                    lexicon_id=self.id,
                     scheme=output_scheme,
                     transliterate_keys=self.transliterate_keys
                 )
