@@ -7,6 +7,7 @@
 import os
 import cmd
 import logging
+from typing import List
 
 from indic_transliteration import sanscript
 from indic_transliteration.sanscript import transliterate
@@ -51,10 +52,10 @@ class CDSLShell(BasicShell):
 
     def __init__(
         self,
-        data_dir=None,
-        dict_ids=None,
-        input_scheme=None,
-        output_scheme=None
+        data_dir: str = None,
+        dict_ids: List[str] = None,
+        input_scheme: str = None,
+        output_scheme: str = None
     ):
         """REPL Interface to CDSL
 
@@ -114,12 +115,13 @@ class CDSLShell(BasicShell):
     # ----------------------------------------------------------------------- #
     # Debug Mode
 
-    def do_debug(self, arg):
+    def do_debug(self, arg: str):
         """Turn debug mode on/off"""
-        if arg.lower() in ["true", "on", "yes"]:
+        arg = arg.lower()
+        if arg in ["true", "on", "yes"]:
             self.debug = True
             self.logger.setLevel(logging.DEBUG)
-        if arg.lower() in ["false", "off", "no"]:
+        if arg in ["false", "off", "no"]:
             self.debug = False
             self.logger.setLevel(logging.INFO)
         print(f"Debug: {self.debug}")
@@ -133,7 +135,7 @@ class CDSLShell(BasicShell):
     def complete_output_scheme(self, text, line, begidx, endidx):
         return [sch for sch in self.schemes if sch.startswith(text)]
 
-    def do_input_scheme(self, scheme):
+    def do_input_scheme(self, scheme: str):
         """Change the input transliteration scheme"""
         if not scheme:
             print(f"Input scheme: {self.input_scheme}")
@@ -144,7 +146,7 @@ class CDSLShell(BasicShell):
                 self.input_scheme = scheme
                 print(f"Input scheme: {self.input_scheme}")
 
-    def do_output_scheme(self, scheme):
+    def do_output_scheme(self, scheme: str):
         """Change the output transliteration scheme"""
         if not scheme:
             print(f"Input scheme: {self.output_scheme}")
@@ -158,7 +160,7 @@ class CDSLShell(BasicShell):
     # ----------------------------------------------------------------------- #
     # Dictionary Information
 
-    def do_info(self, text=None):
+    def do_info(self, text: str = None):
         """Display information about active dictionaries"""
         if self.active_dicts is None:
             self.logger.error("Please select a dictionary first.")
@@ -169,19 +171,19 @@ class CDSLShell(BasicShell):
 
     # ----------------------------------------------------------------------- #
 
-    def do_dicts(self, text=None):
+    def do_dicts(self, text: str = None):
         """Display a list of dictionaries available locally"""
         for _, cdsl_dict in self.cdsl.dicts.items():
             print(cdsl_dict)
 
-    def do_available(self, text=None):
+    def do_available(self, text: str = None):
         """Display a list of dictionaries available in CDSL"""
         for _, cdsl_dict in self.cdsl.available_dicts.items():
             print(cdsl_dict)
 
     # ----------------------------------------------------------------------- #
 
-    def do_update(self, text):
+    def do_update(self, text: str = None):
         """Update loaded dictionaries"""
         self.cdsl.setup(list(self.cdsl.dicts), update=True)
 
@@ -195,27 +197,48 @@ class CDSLShell(BasicShell):
             if dict_id.startswith(last_word)
         ]
 
-    def do_use(self, line):
+    def do_use(self, line: str):
         """
         Load the specified dictionaries from CDSL.
         If not available locally, they will be installed first.
-        """
-        dict_ids = line.upper().split()
 
-        self.active_dicts = []
-        for dict_id in dict_ids:
-            status = (dict_id in self.cdsl.dicts) or self.cdsl.setup([dict_id])
+        * `all` to load all
+        * `none` to unload all
+        """
+        line = line.upper().strip()
+        if not line:
+            print("Please provide dictionary ID(s) to use.")
+            return
+        if line == "NONE":
+            self.active_dicts = []
+        elif line == "ALL":
+            status = self.cdsl.setup()
             if status:
-                self.active_dicts.append(self.cdsl.dicts[dict_id])
+                self.active_dicts = self.cdsl.dicts.values()
             else:
-                self.logger.error(f"Couldn't setup dictionary '{dict_id}'.")
+                self.logger.error("Couldn't setup some dictionary.")
+        else:
+            dict_ids = line.split()
+            self.active_dicts = []
+            for dict_id in dict_ids:
+                status = (
+                    dict_id in self.cdsl.dicts
+                ) or self.cdsl.setup([dict_id])
+                if status:
+                    self.active_dicts.append(self.cdsl.dicts[dict_id])
+                else:
+                    self.logger.error(
+                        f"Couldn't setup dictionary '{dict_id}'."
+                    )
 
         active_count = len(self.active_dicts)
         active_ids = [active_dict.id for active_dict in self.active_dicts]
 
         print(f"Using {active_count} dictionaries: {active_ids}")
 
-        if active_count <= 3:
+        if active_count == 0:
+            active_prompt = "None"
+        elif active_count <= 3:
             active_prompt = ",".join(active_ids)
         else:
             active_prompt = f"{active_ids[0]}+{active_count - 1}"
@@ -223,7 +246,7 @@ class CDSLShell(BasicShell):
 
     # ----------------------------------------------------------------------- #
 
-    def do_show(self, entry_id):
+    def do_show(self, entry_id: str):
         """Show a specific entry by ID"""
         if self.active_dicts is None:
             self.logger.error("Please select a dictionary first.")
@@ -248,7 +271,7 @@ class CDSLShell(BasicShell):
 
     # ----------------------------------------------------------------------- #
 
-    def do_limit(self, text):
+    def do_limit(self, text: str):
         """Limit the number of search results per dictionary"""
         if text:
             try:
@@ -262,13 +285,13 @@ class CDSLShell(BasicShell):
 
     # ----------------------------------------------------------------------- #
 
-    def do_version(self, text):
+    def do_version(self, text: str = None):
         """Show the current version of PyCDSL"""
         print(f"PyCDSL v{__version__}")
 
     # ----------------------------------------------------------------------- #
 
-    def default(self, line):
+    def default(self, line: str):
         if self.active_dicts is None:
             self.logger.error("Please select a dictionary first.")
         else:
@@ -290,7 +313,7 @@ class CDSLShell(BasicShell):
                         )
                     )
 
-    def cmdloop(self, intro=None):
+    def cmdloop(self, intro: str = None):
         print(self.intro)
         print(self.desc)
         self.cdsl.setup(dict_ids=self.dict_ids)
